Class: Aws::BillingConductor::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BillingConductor::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-billingconductor/client.rb,
sig/client.rbs
Overview
An API client for BillingConductor. To construct a client, you need to configure a :region and :credentials.
client = Aws::BillingConductor::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateAccountsResponseSuccess, _AssociatePricingRulesResponseSuccess, _BatchAssociateResourcesToCustomLineItemResponseSuccess, _BatchDisassociateResourcesFromCustomLineItemResponseSuccess, _CreateBillingGroupResponseSuccess, _CreateCustomLineItemResponseSuccess, _CreatePricingPlanResponseSuccess, _CreatePricingRuleResponseSuccess, _DeleteBillingGroupResponseSuccess, _DeleteCustomLineItemResponseSuccess, _DeletePricingPlanResponseSuccess, _DeletePricingRuleResponseSuccess, _DisassociateAccountsResponseSuccess, _DisassociatePricingRulesResponseSuccess, _GetBillingGroupCostReportResponseSuccess, _GetBillingTransferPreferenceResponseSuccess, _ListAccountAssociationsResponseSuccess, _ListBillingGroupCostReportsResponseSuccess, _ListBillingGroupsResponseSuccess, _ListCustomLineItemVersionsResponseSuccess, _ListCustomLineItemsResponseSuccess, _ListPricingPlansAssociatedWithPricingRuleResponseSuccess, _ListPricingPlansResponseSuccess, _ListPricingRulesAssociatedToPricingPlanResponseSuccess, _ListPricingRulesResponseSuccess, _ListResourcesAssociatedToCustomLineItemResponseSuccess, _ListTagsForResourceResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateBillingGroupResponseSuccess, _UpdateBillingTransferPreferenceResponseSuccess, _UpdateCustomLineItemResponseSuccess, _UpdatePricingPlanResponseSuccess, _UpdatePricingRuleResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_accounts(params = {}) ⇒ Types::AssociateAccountsOutput
Connects an array of account IDs in a consolidated billing family to a predefined billing group.
-
#associate_pricing_rules(params = {}) ⇒ Types::AssociatePricingRulesOutput
Connects an array of
PricingRuleArnsto a definedPricingPlan. -
#batch_associate_resources_to_custom_line_item(params = {}) ⇒ Types::BatchAssociateResourcesToCustomLineItemOutput
Associates a batch of resources to a percentage custom line item.
-
#batch_disassociate_resources_from_custom_line_item(params = {}) ⇒ Types::BatchDisassociateResourcesFromCustomLineItemOutput
Disassociates a batch of resources from a percentage custom line item.
-
#create_billing_group(params = {}) ⇒ Types::CreateBillingGroupOutput
Creates a billing group that resembles a consolidated billing family that Amazon Web Services charges, based off of the predefined pricing plan computation.
-
#create_custom_line_item(params = {}) ⇒ Types::CreateCustomLineItemOutput
Creates a custom line item that can be used to create a one-time fixed charge that can be applied to a single billing group for the current or previous billing period.
-
#create_pricing_plan(params = {}) ⇒ Types::CreatePricingPlanOutput
Creates a pricing plan that is used for computing Amazon Web Services charges for billing groups.
-
#create_pricing_rule(params = {}) ⇒ Types::CreatePricingRuleOutput
Creates a pricing rule can be associated to a pricing plan, or a set of pricing plans.
-
#delete_billing_group(params = {}) ⇒ Types::DeleteBillingGroupOutput
Deletes a billing group.
-
#delete_custom_line_item(params = {}) ⇒ Types::DeleteCustomLineItemOutput
Deletes the custom line item identified by the given ARN in the current, or previous billing period.
-
#delete_pricing_plan(params = {}) ⇒ Types::DeletePricingPlanOutput
Deletes a pricing plan.
-
#delete_pricing_rule(params = {}) ⇒ Types::DeletePricingRuleOutput
Deletes the pricing rule that's identified by the input Amazon Resource Name (ARN).
-
#disassociate_accounts(params = {}) ⇒ Types::DisassociateAccountsOutput
Removes the specified list of account IDs from the given billing group.
-
#disassociate_pricing_rules(params = {}) ⇒ Types::DisassociatePricingRulesOutput
Disassociates a list of pricing rules from a pricing plan.
-
#get_billing_group_cost_report(params = {}) ⇒ Types::GetBillingGroupCostReportOutput
Retrieves the margin summary report, which includes the Amazon Web Services cost and charged amount (pro forma cost) by Amazon Web Services service for a specific billing group.
-
#get_billing_transfer_preference(params = {}) ⇒ Types::GetBillingTransferPreferenceOutput
Retrieves the auto billing group creation preference for a billing transfer.
-
#list_account_associations(params = {}) ⇒ Types::ListAccountAssociationsOutput
This is a paginated call to list linked accounts that are linked to the payer account for the specified time period.
-
#list_billing_group_cost_reports(params = {}) ⇒ Types::ListBillingGroupCostReportsOutput
A paginated call to retrieve a summary report of actual Amazon Web Services charges and the calculated Amazon Web Services charges based on the associated pricing plan of a billing group.
-
#list_billing_groups(params = {}) ⇒ Types::ListBillingGroupsOutput
A paginated call to retrieve a list of billing groups for the given billing period.
-
#list_custom_line_item_versions(params = {}) ⇒ Types::ListCustomLineItemVersionsOutput
A paginated call to get a list of all custom line item versions.
-
#list_custom_line_items(params = {}) ⇒ Types::ListCustomLineItemsOutput
A paginated call to get a list of all custom line items (FFLIs) for the given billing period.
-
#list_pricing_plans(params = {}) ⇒ Types::ListPricingPlansOutput
A paginated call to get pricing plans for the given billing period.
-
#list_pricing_plans_associated_with_pricing_rule(params = {}) ⇒ Types::ListPricingPlansAssociatedWithPricingRuleOutput
A list of the pricing plans that are associated with a pricing rule.
-
#list_pricing_rules(params = {}) ⇒ Types::ListPricingRulesOutput
Describes a pricing rule that can be associated to a pricing plan, or set of pricing plans.
-
#list_pricing_rules_associated_to_pricing_plan(params = {}) ⇒ Types::ListPricingRulesAssociatedToPricingPlanOutput
Lists the pricing rules that are associated with a pricing plan.
-
#list_resources_associated_to_custom_line_item(params = {}) ⇒ Types::ListResourcesAssociatedToCustomLineItemOutput
List the resources that are associated to a custom line item.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
A list the tags for a resource.
-
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags to a resource with the specified
resourceArn. -
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from a resource.
-
#update_billing_group(params = {}) ⇒ Types::UpdateBillingGroupOutput
This updates an existing billing group.
-
#update_billing_transfer_preference(params = {}) ⇒ Types::UpdateBillingTransferPreferenceOutput
Sets the auto billing group creation preference for a billing transfer.
-
#update_custom_line_item(params = {}) ⇒ Types::UpdateCustomLineItemOutput
Update an existing custom line item in the current or previous billing period.
-
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanOutput
This updates an existing pricing plan.
-
#update_pricing_rule(params = {}) ⇒ Types::UpdatePricingRuleOutput
Updates an existing pricing rule.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-billingconductor/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2393 2394 2395 |
# File 'lib/aws-sdk-billingconductor/client.rb', line 2393 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2396 2397 2398 |
# File 'lib/aws-sdk-billingconductor/client.rb', line 2396 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#associate_accounts(params = {}) ⇒ Types::AssociateAccountsOutput
Connects an array of account IDs in a consolidated billing family to a predefined billing group. The account IDs must be a part of the consolidated billing family during the current month, and not already associated with another billing group. The maximum number of accounts that can be associated in one call is 30.
86 |
# File 'sig/client.rbs', line 86 def associate_accounts: ( |
#associate_pricing_rules(params = {}) ⇒ Types::AssociatePricingRulesOutput
Connects an array of PricingRuleArns to a defined PricingPlan. The
maximum number PricingRuleArn that can be associated in one call is
30.
97 |
# File 'sig/client.rbs', line 97 def associate_pricing_rules: ( |
#batch_associate_resources_to_custom_line_item(params = {}) ⇒ Types::BatchAssociateResourcesToCustomLineItemOutput
Associates a batch of resources to a percentage custom line item.
109 |
# File 'sig/client.rbs', line 109 def batch_associate_resources_to_custom_line_item: ( |
#batch_disassociate_resources_from_custom_line_item(params = {}) ⇒ Types::BatchDisassociateResourcesFromCustomLineItemOutput
Disassociates a batch of resources from a percentage custom line item.
125 |
# File 'sig/client.rbs', line 125 def batch_disassociate_resources_from_custom_line_item: ( |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 |
# File 'lib/aws-sdk-billingconductor/client.rb', line 2366 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BillingConductor') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-billingconductor' context[:gem_version] = '1.64.0' Seahorse::Client::Request.new(handlers, context) end |
#create_billing_group(params = {}) ⇒ Types::CreateBillingGroupOutput
Creates a billing group that resembles a consolidated billing family that Amazon Web Services charges, based off of the predefined pricing plan computation.
140 |
# File 'sig/client.rbs', line 140 def create_billing_group: ( |
#create_custom_line_item(params = {}) ⇒ Types::CreateCustomLineItemOutput
Creates a custom line item that can be used to create a one-time fixed charge that can be applied to a single billing group for the current or previous billing period. The one-time fixed charge is either a fee or discount.
162 |
# File 'sig/client.rbs', line 162 def create_custom_line_item: ( |
#create_pricing_plan(params = {}) ⇒ Types::CreatePricingPlanOutput
Creates a pricing plan that is used for computing Amazon Web Services charges for billing groups.
203 |
# File 'sig/client.rbs', line 203 def create_pricing_plan: ( |
#create_pricing_rule(params = {}) ⇒ Types::CreatePricingRuleOutput
Creates a pricing rule can be associated to a pricing plan, or a set of pricing plans.
217 |
# File 'sig/client.rbs', line 217 def create_pricing_rule: ( |
#delete_billing_group(params = {}) ⇒ Types::DeleteBillingGroupOutput
Deletes a billing group.
249 |
# File 'sig/client.rbs', line 249 def delete_billing_group: ( |
#delete_custom_line_item(params = {}) ⇒ Types::DeleteCustomLineItemOutput
Deletes the custom line item identified by the given ARN in the current, or previous billing period.
259 |
# File 'sig/client.rbs', line 259 def delete_custom_line_item: ( |
#delete_pricing_plan(params = {}) ⇒ Types::DeletePricingPlanOutput
Deletes a pricing plan. The pricing plan must not be associated with any billing groups to delete successfully.
273 |
# File 'sig/client.rbs', line 273 def delete_pricing_plan: ( |
#delete_pricing_rule(params = {}) ⇒ Types::DeletePricingRuleOutput
Deletes the pricing rule that's identified by the input Amazon Resource Name (ARN).
283 |
# File 'sig/client.rbs', line 283 def delete_pricing_rule: ( |
#disassociate_accounts(params = {}) ⇒ Types::DisassociateAccountsOutput
Removes the specified list of account IDs from the given billing group.
293 |
# File 'sig/client.rbs', line 293 def disassociate_accounts: ( |
#disassociate_pricing_rules(params = {}) ⇒ Types::DisassociatePricingRulesOutput
Disassociates a list of pricing rules from a pricing plan.
304 |
# File 'sig/client.rbs', line 304 def disassociate_pricing_rules: ( |
#get_billing_group_cost_report(params = {}) ⇒ Types::GetBillingGroupCostReportOutput
Retrieves the margin summary report, which includes the Amazon Web Services cost and charged amount (pro forma cost) by Amazon Web Services service for a specific billing group.
316 |
# File 'sig/client.rbs', line 316 def get_billing_group_cost_report: ( |
#get_billing_transfer_preference(params = {}) ⇒ Types::GetBillingTransferPreferenceOutput
Retrieves the auto billing group creation preference for a billing transfer.
335 |
# File 'sig/client.rbs', line 335 def get_billing_transfer_preference: ( |
#list_account_associations(params = {}) ⇒ Types::ListAccountAssociationsOutput
This is a paginated call to list linked accounts that are linked to the payer account for the specified time period. If no information is provided, the current billing period is used. The response will optionally include the billing group that's associated with the linked account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
346 |
# File 'sig/client.rbs', line 346 def list_account_associations: ( |
#list_billing_group_cost_reports(params = {}) ⇒ Types::ListBillingGroupCostReportsOutput
A paginated call to retrieve a summary report of actual Amazon Web Services charges and the calculated Amazon Web Services charges based on the associated pricing plan of a billing group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
363 |
# File 'sig/client.rbs', line 363 def list_billing_group_cost_reports: ( |
#list_billing_groups(params = {}) ⇒ Types::ListBillingGroupsOutput
A paginated call to retrieve a list of billing groups for the given billing period. If you don't provide a billing group, the current billing period is used.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
379 |
# File 'sig/client.rbs', line 379 def list_billing_groups: ( |
#list_custom_line_item_versions(params = {}) ⇒ Types::ListCustomLineItemVersionsOutput
A paginated call to get a list of all custom line item versions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
407 |
# File 'sig/client.rbs', line 407 def list_custom_line_item_versions: ( |
#list_custom_line_items(params = {}) ⇒ Types::ListCustomLineItemsOutput
A paginated call to get a list of all custom line items (FFLIs) for the given billing period. If you don't provide a billing period, the current billing period is used.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
426 |
# File 'sig/client.rbs', line 426 def list_custom_line_items: ( |
#list_pricing_plans(params = {}) ⇒ Types::ListPricingPlansOutput
A paginated call to get pricing plans for the given billing period. If you don't provide a billing period, the current billing period is used.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
446 |
# File 'sig/client.rbs', line 446 def list_pricing_plans: ( |
#list_pricing_plans_associated_with_pricing_rule(params = {}) ⇒ Types::ListPricingPlansAssociatedWithPricingRuleOutput
A list of the pricing plans that are associated with a pricing rule.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
464 |
# File 'sig/client.rbs', line 464 def list_pricing_plans_associated_with_pricing_rule: ( |
#list_pricing_rules(params = {}) ⇒ Types::ListPricingRulesOutput
Describes a pricing rule that can be associated to a pricing plan, or set of pricing plans.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
479 |
# File 'sig/client.rbs', line 479 def list_pricing_rules: ( |
#list_pricing_rules_associated_to_pricing_plan(params = {}) ⇒ Types::ListPricingRulesAssociatedToPricingPlanOutput
Lists the pricing rules that are associated with a pricing plan.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
497 |
# File 'sig/client.rbs', line 497 def list_pricing_rules_associated_to_pricing_plan: ( |
#list_resources_associated_to_custom_line_item(params = {}) ⇒ Types::ListResourcesAssociatedToCustomLineItemOutput
List the resources that are associated to a custom line item.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
512 |
# File 'sig/client.rbs', line 512 def list_resources_associated_to_custom_line_item: ( |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
A list the tags for a resource.
528 |
# File 'sig/client.rbs', line 528 def list_tags_for_resource: ( |
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags to a resource with the specified
resourceArn. If existing tags on a resource are not specified in the
request parameters, they are not changed.
537 |
# File 'sig/client.rbs', line 537 def tag_resource: ( |
#untag_resource(params = {}) ⇒ Struct
Deletes specified tags from a resource.
547 |
# File 'sig/client.rbs', line 547 def untag_resource: ( |
#update_billing_group(params = {}) ⇒ Types::UpdateBillingGroupOutput
This updates an existing billing group.
567 |
# File 'sig/client.rbs', line 567 def update_billing_group: ( |
#update_billing_transfer_preference(params = {}) ⇒ Types::UpdateBillingTransferPreferenceOutput
Sets the auto billing group creation preference for a billing transfer. When the preference is enabled, Billing Conductor automatically creates an indirect billing transfer billing group in your account, with the pricing plan that you specify, for each account that transfers its bill to the bill source account of this billing transfer. The preference applies only to billing groups that are created after you enable it.
Enabling the preference requires the iam:CreateServiceLinkedRole
permission. While a pricing plan is specified in an enabled
preference, you can't delete that pricing plan.
589 |
# File 'sig/client.rbs', line 589 def update_billing_transfer_preference: ( |
#update_custom_line_item(params = {}) ⇒ Types::UpdateCustomLineItemOutput
Update an existing custom line item in the current or previous billing period.
610 |
# File 'sig/client.rbs', line 610 def update_custom_line_item: ( |
#update_pricing_plan(params = {}) ⇒ Types::UpdatePricingPlanOutput
This updates an existing pricing plan.
646 |
# File 'sig/client.rbs', line 646 def update_pricing_plan: ( |
#update_pricing_rule(params = {}) ⇒ Types::UpdatePricingRuleOutput
Updates an existing pricing rule.
670 |
# File 'sig/client.rbs', line 670 def update_pricing_rule: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2386 2387 2388 |
# File 'lib/aws-sdk-billingconductor/client.rb', line 2386 def waiter_names [] end |