Class: Aws::BillingConductor::Types::AutoTransferBillingGroupCreationPreference

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

The auto billing group creation preference for a billing transfer. When the preference is enabled, Billing Conductor automatically creates an indirect billing transfer billing group, with the specified pricing plan, for each account that transfers its bill to the bill source account of the billing transfer.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#enabled ⇒ Boolean

Specifies whether Billing Conductor automatically creates billing groups for the billing transfer. The preference is disabled by default.

Returns:

  • (Boolean)


229
230
231
232
233
234
# File 'lib/aws-sdk-billingconductor/types.rb', line 229

class AutoTransferBillingGroupCreationPreference < Struct.new(
  :enabled,
  :pricing_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end

#pricing_plan_arn ⇒ String

The Amazon Resource Name (ARN) of the pricing plan to apply to the automatically created billing groups. This value is required when Enabled is true, and must be omitted when Enabled is false.

Returns:

  • (String)


229
230
231
232
233
234
# File 'lib/aws-sdk-billingconductor/types.rb', line 229

class AutoTransferBillingGroupCreationPreference < Struct.new(
  :enabled,
  :pricing_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end