Class: Aws::BillingConductor::Types::BatchAssociateResourcesToCustomLineItemInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BillingConductor::Types::BatchAssociateResourcesToCustomLineItemInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billingconductor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#billing_period_range ⇒ Types::CustomLineItemBillingPeriodRange
The billing period range in which the custom line item request will be applied.
-
#resource_arns ⇒ Array<String>
A list containing the ARNs of the resources to be associated.
-
#target_arn ⇒ String
A percentage custom line item ARN to associate the resources to.
Instance Attribute Details
#billing_period_range ⇒ Types::CustomLineItemBillingPeriodRange
The billing period range in which the custom line item request will be applied.
251 252 253 254 255 256 257 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 251 class BatchAssociateResourcesToCustomLineItemInput < Struct.new( :target_arn, :resource_arns, :billing_period_range) SENSITIVE = [] include Aws::Structure end |
#resource_arns ⇒ Array<String>
A list containing the ARNs of the resources to be associated.
251 252 253 254 255 256 257 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 251 class BatchAssociateResourcesToCustomLineItemInput < Struct.new( :target_arn, :resource_arns, :billing_period_range) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
A percentage custom line item ARN to associate the resources to.
251 252 253 254 255 256 257 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 251 class BatchAssociateResourcesToCustomLineItemInput < Struct.new( :target_arn, :resource_arns, :billing_period_range) SENSITIVE = [] include Aws::Structure end |