Class: Aws::BillingConductor::Types::BatchAssociateResourcesToCustomLineItemOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failed_associated_resources ⇒ Array<Types::AssociateResourceResponseElement>

A list of AssociateResourceResponseElement for each resource that failed association to a percentage custom line item.



272
273
274
275
276
277
# File 'lib/aws-sdk-billingconductor/types.rb', line 272

class BatchAssociateResourcesToCustomLineItemOutput < Struct.new(
  :successfully_associated_resources,
  :failed_associated_resources)
  SENSITIVE = []
  include Aws::Structure
end

#successfully_associated_resources ⇒ Array<Types::AssociateResourceResponseElement>

A list of AssociateResourceResponseElement for each resource that's been associated to a percentage custom line item successfully.



272
273
274
275
276
277
# File 'lib/aws-sdk-billingconductor/types.rb', line 272

class BatchAssociateResourcesToCustomLineItemOutput < Struct.new(
  :successfully_associated_resources,
  :failed_associated_resources)
  SENSITIVE = []
  include Aws::Structure
end