Class: Aws::BillingConductor::Types::ComputationPreference

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

The preferences and settings that will be used to compute the Amazon Web Services charges for a billing group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#pricing_plan_arn ⇒ String

The Amazon Resource Name (ARN) of the pricing plan that's used to compute the Amazon Web Services charges for a billing group.

Returns:

  • (String)


524
525
526
527
528
# File 'lib/aws-sdk-billingconductor/types.rb', line 524

class ComputationPreference < Struct.new(
  :pricing_plan_arn)
  SENSITIVE = []
  include Aws::Structure
end