Class: Aws::BillingConductor::Types::CreateBillingGroupInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#account_grouping ⇒ Types::AccountGrouping

The set of accounts that will be under the billing group. The set of accounts resemble the linked accounts in a consolidated billing family.



600
601
602
603
604
605
606
607
608
609
610
# File 'lib/aws-sdk-billingconductor/types.rb', line 600

class CreateBillingGroupInput < Struct.new(
  :client_token,
  :name,
  :account_grouping,
  :computation_preference,
  :primary_account_id,
  :description,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#client_token ⇒ String

A unique, case-sensitive identifier that you specify to ensure idempotency of the request. Idempotency ensures that an API request completes no more than one time. With an idempotent request, if the original request completes successfully, any subsequent retries complete successfully without performing any further actions.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


600
601
602
603
604
605
606
607
608
609
610
# File 'lib/aws-sdk-billingconductor/types.rb', line 600

class CreateBillingGroupInput < Struct.new(
  :client_token,
  :name,
  :account_grouping,
  :computation_preference,
  :primary_account_id,
  :description,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#computation_preference ⇒ Types::ComputationPreference

The preferences and settings that will be used to compute the Amazon Web Services charges for a billing group.



600
601
602
603
604
605
606
607
608
609
610
# File 'lib/aws-sdk-billingconductor/types.rb', line 600

class CreateBillingGroupInput < Struct.new(
  :client_token,
  :name,
  :account_grouping,
  :computation_preference,
  :primary_account_id,
  :description,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#description ⇒ String

The description of the billing group.

Returns:

  • (String)


600
601
602
603
604
605
606
607
608
609
610
# File 'lib/aws-sdk-billingconductor/types.rb', line 600

class CreateBillingGroupInput < Struct.new(
  :client_token,
  :name,
  :account_grouping,
  :computation_preference,
  :primary_account_id,
  :description,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#name ⇒ String

The billing group name. The names must be unique.

Returns:

  • (String)


600
601
602
603
604
605
606
607
608
609
610
# File 'lib/aws-sdk-billingconductor/types.rb', line 600

class CreateBillingGroupInput < Struct.new(
  :client_token,
  :name,
  :account_grouping,
  :computation_preference,
  :primary_account_id,
  :description,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#primary_account_id ⇒ String

The account ID that serves as the main account in a billing group.

Returns:

  • (String)


600
601
602
603
604
605
606
607
608
609
610
# File 'lib/aws-sdk-billingconductor/types.rb', line 600

class CreateBillingGroupInput < Struct.new(
  :client_token,
  :name,
  :account_grouping,
  :computation_preference,
  :primary_account_id,
  :description,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

A map that contains tag keys and tag values that are attached to a billing group. This feature isn't available during the beta.

Returns:

  • (Hash<String,String>)


600
601
602
603
604
605
606
607
608
609
610
# File 'lib/aws-sdk-billingconductor/types.rb', line 600

class CreateBillingGroupInput < Struct.new(
  :client_token,
  :name,
  :account_grouping,
  :computation_preference,
  :primary_account_id,
  :description,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end