Class: Aws::BillingConductor::Types::CreatePricingPlanInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

A unique, case-sensitive identifier that you specify to ensure idempotency of the request. Idempotency ensures that an API request completes no more than one time. With an idempotent request, if the original request completes successfully, any subsequent retries complete successfully without performing any further actions.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


753
754
755
756
757
758
759
760
761
# File 'lib/aws-sdk-billingconductor/types.rb', line 753

class CreatePricingPlanInput < Struct.new(
  :client_token,
  :name,
  :description,
  :pricing_rule_arns,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#description ⇒ String

The description of the pricing plan.

Returns:

  • (String)


753
754
755
756
757
758
759
760
761
# File 'lib/aws-sdk-billingconductor/types.rb', line 753

class CreatePricingPlanInput < Struct.new(
  :client_token,
  :name,
  :description,
  :pricing_rule_arns,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#name ⇒ String

The name of the pricing plan. The names must be unique to each pricing plan.

Returns:

  • (String)


753
754
755
756
757
758
759
760
761
# File 'lib/aws-sdk-billingconductor/types.rb', line 753

class CreatePricingPlanInput < Struct.new(
  :client_token,
  :name,
  :description,
  :pricing_rule_arns,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#pricing_rule_arns ⇒ Array<String>

A list of Amazon Resource Names (ARNs) that define the pricing plan parameters.

Returns:

  • (Array<String>)


753
754
755
756
757
758
759
760
761
# File 'lib/aws-sdk-billingconductor/types.rb', line 753

class CreatePricingPlanInput < Struct.new(
  :client_token,
  :name,
  :description,
  :pricing_rule_arns,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

A map that contains tag keys and tag values that are attached to a pricing plan.

Returns:

  • (Hash<String,String>)


753
754
755
756
757
758
759
760
761
# File 'lib/aws-sdk-billingconductor/types.rb', line 753

class CreatePricingPlanInput < Struct.new(
  :client_token,
  :name,
  :description,
  :pricing_rule_arns,
  :tags)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end