Class: Aws::BillingConductor::Types::CreateTieringInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

The set of tiering configurations for the pricing rule.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_tiers ⇒ Array<Types::CustomTier>

The set of custom tiers for the pricing rule.



892
893
894
895
896
897
# File 'lib/aws-sdk-billingconductor/types.rb', line 892

class CreateTieringInput < Struct.new(
  :free_tier,
  :custom_tiers)
  SENSITIVE = []
  include Aws::Structure
end

#free_tier ⇒ Types::CreateFreeTierConfig

The possible Amazon Web Services Free Tier configurations.



892
893
894
895
896
897
# File 'lib/aws-sdk-billingconductor/types.rb', line 892

class CreateTieringInput < Struct.new(
  :free_tier,
  :custom_tiers)
  SENSITIVE = []
  include Aws::Structure
end