Class: Aws::BillingConductor::Types::CustomLineItemChargeDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

The charge details of a custom line item. It should contain only one of Flat or Percentage.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#flat ⇒ Types::CustomLineItemFlatChargeDetails

A CustomLineItemFlatChargeDetails that describes the charge details of a flat custom line item.



945
946
947
948
949
950
951
952
# File 'lib/aws-sdk-billingconductor/types.rb', line 945

class CustomLineItemChargeDetails < Struct.new(
  :flat,
  :percentage,
  :type,
  :line_item_filters)
  SENSITIVE = []
  include Aws::Structure
end

#line_item_filters ⇒ Array<Types::LineItemFilter>

A representation of the line item filter.



945
946
947
948
949
950
951
952
# File 'lib/aws-sdk-billingconductor/types.rb', line 945

class CustomLineItemChargeDetails < Struct.new(
  :flat,
  :percentage,
  :type,
  :line_item_filters)
  SENSITIVE = []
  include Aws::Structure
end

#percentage ⇒ Types::CustomLineItemPercentageChargeDetails

A CustomLineItemPercentageChargeDetails that describes the charge details of a percentage custom line item.



945
946
947
948
949
950
951
952
# File 'lib/aws-sdk-billingconductor/types.rb', line 945

class CustomLineItemChargeDetails < Struct.new(
  :flat,
  :percentage,
  :type,
  :line_item_filters)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The type of the custom line item that indicates whether the charge is a fee or credit.



945
946
947
948
949
950
951
952
# File 'lib/aws-sdk-billingconductor/types.rb', line 945

class CustomLineItemChargeDetails < Struct.new(
  :flat,
  :percentage,
  :type,
  :line_item_filters)
  SENSITIVE = []
  include Aws::Structure
end