Class: Aws::BillingConductor::Types::DeleteCustomLineItemInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The ARN of the custom line item to be deleted.

Returns:

  • (String)


1231
1232
1233
1234
1235
1236
# File 'lib/aws-sdk-billingconductor/types.rb', line 1231

class DeleteCustomLineItemInput < Struct.new(
  :arn,
  :billing_period_range)
  SENSITIVE = []
  include Aws::Structure
end

#billing_period_range ⇒ Types::CustomLineItemBillingPeriodRange

The billing period range in which the custom line item request will be applied.



1231
1232
1233
1234
1235
1236
# File 'lib/aws-sdk-billingconductor/types.rb', line 1231

class DeleteCustomLineItemInput < Struct.new(
  :arn,
  :billing_period_range)
  SENSITIVE = []
  include Aws::Structure
end