Class: Aws::BillingConductor::Types::DisassociateResourceResponseElement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

A resource disassociation result for a percentage custom line item.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The resource ARN that was disassociated from the custom line item.

Returns:

  • (String)


1376
1377
1378
1379
1380
1381
# File 'lib/aws-sdk-billingconductor/types.rb', line 1376

class DisassociateResourceResponseElement < Struct.new(
  :arn,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#error ⇒ Types::AssociateResourceError

An AssociateResourceError that's shown if the resource disassociation fails.



1376
1377
1378
1379
1380
1381
# File 'lib/aws-sdk-billingconductor/types.rb', line 1376

class DisassociateResourceResponseElement < Struct.new(
  :arn,
  :error)
  SENSITIVE = []
  include Aws::Structure
end