Class: Aws::BillingConductor::Types::GetBillingTransferPreferenceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BillingConductor::Types::GetBillingTransferPreferenceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billingconductor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#responsibility_transfer_arn ⇒ String
The Amazon Resource Name (ARN) of the billing transfer whose preference you want to retrieve.
Instance Attribute Details
#responsibility_transfer_arn ⇒ String
The Amazon Resource Name (ARN) of the billing transfer whose preference you want to retrieve.
1458 1459 1460 1461 1462 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 1458 class GetBillingTransferPreferenceInput < Struct.new( :responsibility_transfer_arn) SENSITIVE = [] include Aws::Structure end |