Class: Aws::BillingConductor::Types::GetBillingTransferPreferenceOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_billing_transfer_billing_group_creation ⇒ Types::AutoTransferBillingGroupCreationPreference

The auto billing group creation preference for the billing transfer.



1480
1481
1482
1483
1484
1485
1486
# File 'lib/aws-sdk-billingconductor/types.rb', line 1480

class GetBillingTransferPreferenceOutput < Struct.new(
  :responsibility_transfer_arn,
  :auto_billing_transfer_billing_group_creation,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_time ⇒ Integer

The most recent time when the preference was modified. This value is empty if the preference has never been set for the billing transfer.

Returns:

  • (Integer)


1480
1481
1482
1483
1484
1485
1486
# File 'lib/aws-sdk-billingconductor/types.rb', line 1480

class GetBillingTransferPreferenceOutput < Struct.new(
  :responsibility_transfer_arn,
  :auto_billing_transfer_billing_group_creation,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#responsibility_transfer_arn ⇒ String

The Amazon Resource Name (ARN) of the billing transfer that the preference applies to.

Returns:

  • (String)


1480
1481
1482
1483
1484
1485
1486
# File 'lib/aws-sdk-billingconductor/types.rb', line 1480

class GetBillingTransferPreferenceOutput < Struct.new(
  :responsibility_transfer_arn,
  :auto_billing_transfer_billing_group_creation,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end