Class: Aws::BillingConductor::Types::PresentationObject

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

An object that defines how custom line item charges are presented in the bill, containing specifications for service presentation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#service ⇒ String

The service under which the custom line item charges will be presented. Must be a string between 1 and 128 characters matching the pattern "^[a-zA-Z0-9]+$".

Returns:

  • (String)


2447
2448
2449
2450
2451
# File 'lib/aws-sdk-billingconductor/types.rb', line 2447

class PresentationObject < Struct.new(
  :service)
  SENSITIVE = []
  include Aws::Structure
end