Class: Aws::BillingConductor::Types::ServiceLimitExceededException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

The request would cause a service limit to exceed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#limit_code ⇒ String

The unique code identifier of the service limit that is being exceeded.

Returns:

  • (String)


2637
2638
2639
2640
2641
2642
2643
2644
2645
# File 'lib/aws-sdk-billingconductor/types.rb', line 2637

class ServiceLimitExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :limit_code,
  :service_code)
  SENSITIVE = []
  include Aws::Structure
end

#message ⇒ String

Returns:

  • (String)


2637
2638
2639
2640
2641
2642
2643
2644
2645
# File 'lib/aws-sdk-billingconductor/types.rb', line 2637

class ServiceLimitExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :limit_code,
  :service_code)
  SENSITIVE = []
  include Aws::Structure
end

#resource_id ⇒ String

Identifier of the resource affected.

Returns:

  • (String)


2637
2638
2639
2640
2641
2642
2643
2644
2645
# File 'lib/aws-sdk-billingconductor/types.rb', line 2637

class ServiceLimitExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :limit_code,
  :service_code)
  SENSITIVE = []
  include Aws::Structure
end

#resource_type ⇒ String

Type of the resource affected.

Returns:

  • (String)


2637
2638
2639
2640
2641
2642
2643
2644
2645
# File 'lib/aws-sdk-billingconductor/types.rb', line 2637

class ServiceLimitExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :limit_code,
  :service_code)
  SENSITIVE = []
  include Aws::Structure
end

#service_code ⇒ String

The unique code for the service of the limit that is being exceeded.

Returns:

  • (String)


2637
2638
2639
2640
2641
2642
2643
2644
2645
# File 'lib/aws-sdk-billingconductor/types.rb', line 2637

class ServiceLimitExceededException < Struct.new(
  :message,
  :resource_id,
  :resource_type,
  :limit_code,
  :service_code)
  SENSITIVE = []
  include Aws::Structure
end