Class: Aws::BillingConductor::Types::StringSearch

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

A structure that defines string search parameters.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#search_option ⇒ String

The search option to be applied when performing the string search.

Returns:

  • (String)


2659
2660
2661
2662
2663
2664
# File 'lib/aws-sdk-billingconductor/types.rb', line 2659

class StringSearch < Struct.new(
  :search_option,
  :search_value)
  SENSITIVE = []
  include Aws::Structure
end

#search_value ⇒ String

The value to search for within the specified string field.

Returns:

  • (String)


2659
2660
2661
2662
2663
2664
# File 'lib/aws-sdk-billingconductor/types.rb', line 2659

class StringSearch < Struct.new(
  :search_option,
  :search_value)
  SENSITIVE = []
  include Aws::Structure
end