Class: Aws::BillingConductor::Types::UpdateBillingGroupAccountGrouping

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

Specifies if the billing group has the following features enabled.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_associate ⇒ Boolean

Specifies if this billing group will automatically associate newly added Amazon Web Services accounts that join your consolidated billing family.

Returns:

  • (Boolean)


2762
2763
2764
2765
2766
2767
# File 'lib/aws-sdk-billingconductor/types.rb', line 2762

class UpdateBillingGroupAccountGrouping < Struct.new(
  :auto_associate,
  :responsibility_transfer_arn)
  SENSITIVE = []
  include Aws::Structure
end

#responsibility_transfer_arn ⇒ String

The Amazon Resource Name (ARN) that identifies the transfer relationship. Note: Modifications to the ResponsibilityTransferArn are not permitted for existing billing groups.

Returns:

  • (String)


2762
2763
2764
2765
2766
2767
# File 'lib/aws-sdk-billingconductor/types.rb', line 2762

class UpdateBillingGroupAccountGrouping < Struct.new(
  :auto_associate,
  :responsibility_transfer_arn)
  SENSITIVE = []
  include Aws::Structure
end