Class: Aws::BillingConductor::Types::UpdateBillingGroupInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#account_grouping ⇒ Types::UpdateBillingGroupAccountGrouping

Specifies if the billing group has automatic account association (AutoAssociate) enabled.



2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
# File 'lib/aws-sdk-billingconductor/types.rb', line 2799

class UpdateBillingGroupInput < Struct.new(
  :arn,
  :name,
  :status,
  :computation_preference,
  :description,
  :account_grouping)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#arn ⇒ String

The Amazon Resource Name (ARN) of the billing group being updated.

Returns:

  • (String)


2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
# File 'lib/aws-sdk-billingconductor/types.rb', line 2799

class UpdateBillingGroupInput < Struct.new(
  :arn,
  :name,
  :status,
  :computation_preference,
  :description,
  :account_grouping)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#computation_preference ⇒ Types::ComputationPreference

The preferences and settings that will be used to compute the Amazon Web Services charges for a billing group.



2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
# File 'lib/aws-sdk-billingconductor/types.rb', line 2799

class UpdateBillingGroupInput < Struct.new(
  :arn,
  :name,
  :status,
  :computation_preference,
  :description,
  :account_grouping)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#description ⇒ String

A description of the billing group.

Returns:

  • (String)


2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
# File 'lib/aws-sdk-billingconductor/types.rb', line 2799

class UpdateBillingGroupInput < Struct.new(
  :arn,
  :name,
  :status,
  :computation_preference,
  :description,
  :account_grouping)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#name ⇒ String

The name of the billing group. The names must be unique to each billing group.

Returns:

  • (String)


2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
# File 'lib/aws-sdk-billingconductor/types.rb', line 2799

class UpdateBillingGroupInput < Struct.new(
  :arn,
  :name,
  :status,
  :computation_preference,
  :description,
  :account_grouping)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#status ⇒ String

The status of the billing group. Only one of the valid values can be used.

Returns:

  • (String)


2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
# File 'lib/aws-sdk-billingconductor/types.rb', line 2799

class UpdateBillingGroupInput < Struct.new(
  :arn,
  :name,
  :status,
  :computation_preference,
  :description,
  :account_grouping)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end