Class: Aws::BillingConductor::Types::UpdateBillingGroupOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#account_grouping ⇒ Types::UpdateBillingGroupAccountGrouping

Specifies if the billing group has automatic account association (AutoAssociate) enabled.



2857
2858
2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
# File 'lib/aws-sdk-billingconductor/types.rb', line 2857

class UpdateBillingGroupOutput < Struct.new(
  :arn,
  :name,
  :description,
  :primary_account_id,
  :pricing_plan_arn,
  :size,
  :last_modified_time,
  :status,
  :status_reason,
  :account_grouping)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#arn ⇒ String

The Amazon Resource Name (ARN) of the billing group that was updated.

Returns:

  • (String)


2857
2858
2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
# File 'lib/aws-sdk-billingconductor/types.rb', line 2857

class UpdateBillingGroupOutput < Struct.new(
  :arn,
  :name,
  :description,
  :primary_account_id,
  :pricing_plan_arn,
  :size,
  :last_modified_time,
  :status,
  :status_reason,
  :account_grouping)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#description ⇒ String

A description of the billing group.

Returns:

  • (String)


2857
2858
2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
# File 'lib/aws-sdk-billingconductor/types.rb', line 2857

class UpdateBillingGroupOutput < Struct.new(
  :arn,
  :name,
  :description,
  :primary_account_id,
  :pricing_plan_arn,
  :size,
  :last_modified_time,
  :status,
  :status_reason,
  :account_grouping)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#last_modified_time ⇒ Integer

The most recent time when the billing group was modified.

Returns:

  • (Integer)


2857
2858
2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
# File 'lib/aws-sdk-billingconductor/types.rb', line 2857

class UpdateBillingGroupOutput < Struct.new(
  :arn,
  :name,
  :description,
  :primary_account_id,
  :pricing_plan_arn,
  :size,
  :last_modified_time,
  :status,
  :status_reason,
  :account_grouping)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#name ⇒ String

The name of the billing group. The names must be unique to each billing group.

Returns:

  • (String)


2857
2858
2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
# File 'lib/aws-sdk-billingconductor/types.rb', line 2857

class UpdateBillingGroupOutput < Struct.new(
  :arn,
  :name,
  :description,
  :primary_account_id,
  :pricing_plan_arn,
  :size,
  :last_modified_time,
  :status,
  :status_reason,
  :account_grouping)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#pricing_plan_arn ⇒ String

The Amazon Resource Name (ARN) of the pricing plan to compute Amazon Web Services charges for the billing group.

Returns:

  • (String)


2857
2858
2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
# File 'lib/aws-sdk-billingconductor/types.rb', line 2857

class UpdateBillingGroupOutput < Struct.new(
  :arn,
  :name,
  :description,
  :primary_account_id,
  :pricing_plan_arn,
  :size,
  :last_modified_time,
  :status,
  :status_reason,
  :account_grouping)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#primary_account_id ⇒ String

The account ID that serves as the main account in a billing group.

Returns:

  • (String)


2857
2858
2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
# File 'lib/aws-sdk-billingconductor/types.rb', line 2857

class UpdateBillingGroupOutput < Struct.new(
  :arn,
  :name,
  :description,
  :primary_account_id,
  :pricing_plan_arn,
  :size,
  :last_modified_time,
  :status,
  :status_reason,
  :account_grouping)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#size ⇒ Integer

The number of accounts in the particular billing group.

Returns:

  • (Integer)


2857
2858
2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
# File 'lib/aws-sdk-billingconductor/types.rb', line 2857

class UpdateBillingGroupOutput < Struct.new(
  :arn,
  :name,
  :description,
  :primary_account_id,
  :pricing_plan_arn,
  :size,
  :last_modified_time,
  :status,
  :status_reason,
  :account_grouping)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#status ⇒ String

The status of the billing group. Only one of the valid values can be used.

Returns:

  • (String)


2857
2858
2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
# File 'lib/aws-sdk-billingconductor/types.rb', line 2857

class UpdateBillingGroupOutput < Struct.new(
  :arn,
  :name,
  :description,
  :primary_account_id,
  :pricing_plan_arn,
  :size,
  :last_modified_time,
  :status,
  :status_reason,
  :account_grouping)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#status_reason ⇒ String

The reason why the billing group is in its current status.

Returns:

  • (String)


2857
2858
2859
2860
2861
2862
2863
2864
2865
2866
2867
2868
2869
2870
# File 'lib/aws-sdk-billingconductor/types.rb', line 2857

class UpdateBillingGroupOutput < Struct.new(
  :arn,
  :name,
  :description,
  :primary_account_id,
  :pricing_plan_arn,
  :size,
  :last_modified_time,
  :status,
  :status_reason,
  :account_grouping)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end