Class: Aws::BillingConductor::Types::UpdateBillingTransferPreferenceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BillingConductor::Types::UpdateBillingTransferPreferenceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billingconductor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_billing_transfer_billing_group_creation ⇒ Types::AutoTransferBillingGroupCreationPreference
The auto billing group creation preference to set for the billing transfer.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you specify to ensure idempotency of the request.
-
#responsibility_transfer_arn ⇒ String
The Amazon Resource Name (ARN) of the billing transfer whose preference you want to set.
Instance Attribute Details
#auto_billing_transfer_billing_group_creation ⇒ Types::AutoTransferBillingGroupCreationPreference
The auto billing group creation preference to set for the billing transfer.
2895 2896 2897 2898 2899 2900 2901 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 2895 class UpdateBillingTransferPreferenceInput < Struct.new( :client_token, :responsibility_transfer_arn, :auto_billing_transfer_billing_group_creation) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you specify to ensure idempotency of the request. Idempotency ensures that an API request completes no more than one time. With an idempotent request, if the original request completes successfully, any subsequent retries complete successfully without performing any further actions.
A suitable default value is auto-generated. You should normally not need to pass this option.
2895 2896 2897 2898 2899 2900 2901 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 2895 class UpdateBillingTransferPreferenceInput < Struct.new( :client_token, :responsibility_transfer_arn, :auto_billing_transfer_billing_group_creation) SENSITIVE = [] include Aws::Structure end |
#responsibility_transfer_arn ⇒ String
The Amazon Resource Name (ARN) of the billing transfer whose preference you want to set.
2895 2896 2897 2898 2899 2900 2901 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 2895 class UpdateBillingTransferPreferenceInput < Struct.new( :client_token, :responsibility_transfer_arn, :auto_billing_transfer_billing_group_creation) SENSITIVE = [] include Aws::Structure end |