Class: Aws::BillingConductor::Types::UpdateCustomLineItemChargeDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

A representation of the new charge details of a custom line item. This should contain only one of Flat or Percentage.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#flat ⇒ Types::UpdateCustomLineItemFlatChargeDetails

An UpdateCustomLineItemFlatChargeDetails that describes the new charge details of a flat custom line item.



2946
2947
2948
2949
2950
2951
2952
# File 'lib/aws-sdk-billingconductor/types.rb', line 2946

class UpdateCustomLineItemChargeDetails < Struct.new(
  :flat,
  :percentage,
  :line_item_filters)
  SENSITIVE = []
  include Aws::Structure
end

#line_item_filters ⇒ Array<Types::LineItemFilter>

A representation of the line item filter.

Returns:



2946
2947
2948
2949
2950
2951
2952
# File 'lib/aws-sdk-billingconductor/types.rb', line 2946

class UpdateCustomLineItemChargeDetails < Struct.new(
  :flat,
  :percentage,
  :line_item_filters)
  SENSITIVE = []
  include Aws::Structure
end

#percentage ⇒ Types::UpdateCustomLineItemPercentageChargeDetails

An UpdateCustomLineItemPercentageChargeDetails that describes the new charge details of a percentage custom line item.



2946
2947
2948
2949
2950
2951
2952
# File 'lib/aws-sdk-billingconductor/types.rb', line 2946

class UpdateCustomLineItemChargeDetails < Struct.new(
  :flat,
  :percentage,
  :line_item_filters)
  SENSITIVE = []
  include Aws::Structure
end