Class: Aws::BillingConductor::Types::UpdateCustomLineItemInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The ARN of the custom line item to be updated.

Returns:

  • (String)


2993
2994
2995
2996
2997
2998
2999
3000
3001
# File 'lib/aws-sdk-billingconductor/types.rb', line 2993

class UpdateCustomLineItemInput < Struct.new(
  :arn,
  :name,
  :description,
  :charge_details,
  :billing_period_range)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#billing_period_range ⇒ Types::CustomLineItemBillingPeriodRange

The billing period range in which the custom line item request will be applied.



2993
2994
2995
2996
2997
2998
2999
3000
3001
# File 'lib/aws-sdk-billingconductor/types.rb', line 2993

class UpdateCustomLineItemInput < Struct.new(
  :arn,
  :name,
  :description,
  :charge_details,
  :billing_period_range)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#charge_details ⇒ Types::UpdateCustomLineItemChargeDetails

A ListCustomLineItemChargeDetails containing the new charge details for the custom line item.



2993
2994
2995
2996
2997
2998
2999
3000
3001
# File 'lib/aws-sdk-billingconductor/types.rb', line 2993

class UpdateCustomLineItemInput < Struct.new(
  :arn,
  :name,
  :description,
  :charge_details,
  :billing_period_range)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#description ⇒ String

The new line item description of the custom line item.

Returns:

  • (String)


2993
2994
2995
2996
2997
2998
2999
3000
3001
# File 'lib/aws-sdk-billingconductor/types.rb', line 2993

class UpdateCustomLineItemInput < Struct.new(
  :arn,
  :name,
  :description,
  :charge_details,
  :billing_period_range)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#name ⇒ String

The new name for the custom line item.

Returns:

  • (String)


2993
2994
2995
2996
2997
2998
2999
3000
3001
# File 'lib/aws-sdk-billingconductor/types.rb', line 2993

class UpdateCustomLineItemInput < Struct.new(
  :arn,
  :name,
  :description,
  :charge_details,
  :billing_period_range)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end