Class: Aws::BillingConductor::Types::UpdateCustomLineItemOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The ARN of the successfully updated custom line item.

Returns:

  • (String)


3035
3036
3037
3038
3039
3040
3041
3042
3043
3044
3045
# File 'lib/aws-sdk-billingconductor/types.rb', line 3035

class UpdateCustomLineItemOutput < Struct.new(
  :arn,
  :billing_group_arn,
  :name,
  :description,
  :charge_details,
  :last_modified_time,
  :association_size)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#association_size ⇒ Integer

The number of resources that are associated to the custom line item.

Returns:

  • (Integer)


3035
3036
3037
3038
3039
3040
3041
3042
3043
3044
3045
# File 'lib/aws-sdk-billingconductor/types.rb', line 3035

class UpdateCustomLineItemOutput < Struct.new(
  :arn,
  :billing_group_arn,
  :name,
  :description,
  :charge_details,
  :last_modified_time,
  :association_size)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#billing_group_arn ⇒ String

The ARN of the billing group that the custom line item is applied to.

Returns:

  • (String)


3035
3036
3037
3038
3039
3040
3041
3042
3043
3044
3045
# File 'lib/aws-sdk-billingconductor/types.rb', line 3035

class UpdateCustomLineItemOutput < Struct.new(
  :arn,
  :billing_group_arn,
  :name,
  :description,
  :charge_details,
  :last_modified_time,
  :association_size)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#charge_details ⇒ Types::ListCustomLineItemChargeDetails

A ListCustomLineItemChargeDetails containing the charge details of the successfully updated custom line item.



3035
3036
3037
3038
3039
3040
3041
3042
3043
3044
3045
# File 'lib/aws-sdk-billingconductor/types.rb', line 3035

class UpdateCustomLineItemOutput < Struct.new(
  :arn,
  :billing_group_arn,
  :name,
  :description,
  :charge_details,
  :last_modified_time,
  :association_size)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#description ⇒ String

The description of the successfully updated custom line item.

Returns:

  • (String)


3035
3036
3037
3038
3039
3040
3041
3042
3043
3044
3045
# File 'lib/aws-sdk-billingconductor/types.rb', line 3035

class UpdateCustomLineItemOutput < Struct.new(
  :arn,
  :billing_group_arn,
  :name,
  :description,
  :charge_details,
  :last_modified_time,
  :association_size)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#last_modified_time ⇒ Integer

The most recent time when the custom line item was modified.

Returns:

  • (Integer)


3035
3036
3037
3038
3039
3040
3041
3042
3043
3044
3045
# File 'lib/aws-sdk-billingconductor/types.rb', line 3035

class UpdateCustomLineItemOutput < Struct.new(
  :arn,
  :billing_group_arn,
  :name,
  :description,
  :charge_details,
  :last_modified_time,
  :association_size)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#name ⇒ String

The name of the successfully updated custom line item.

Returns:

  • (String)


3035
3036
3037
3038
3039
3040
3041
3042
3043
3044
3045
# File 'lib/aws-sdk-billingconductor/types.rb', line 3035

class UpdateCustomLineItemOutput < Struct.new(
  :arn,
  :billing_group_arn,
  :name,
  :description,
  :charge_details,
  :last_modified_time,
  :association_size)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end