Class: Aws::BillingConductor::Types::UpdatePricingPlanOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the updated pricing plan.

Returns:

  • (String)


3126
3127
3128
3129
3130
3131
3132
3133
3134
# File 'lib/aws-sdk-billingconductor/types.rb', line 3126

class UpdatePricingPlanOutput < Struct.new(
  :arn,
  :name,
  :description,
  :size,
  :last_modified_time)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#description ⇒ String

The new description for the pricing rule.

Returns:

  • (String)


3126
3127
3128
3129
3130
3131
3132
3133
3134
# File 'lib/aws-sdk-billingconductor/types.rb', line 3126

class UpdatePricingPlanOutput < Struct.new(
  :arn,
  :name,
  :description,
  :size,
  :last_modified_time)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#last_modified_time ⇒ Integer

The most recent time when the pricing plan was modified.

Returns:

  • (Integer)


3126
3127
3128
3129
3130
3131
3132
3133
3134
# File 'lib/aws-sdk-billingconductor/types.rb', line 3126

class UpdatePricingPlanOutput < Struct.new(
  :arn,
  :name,
  :description,
  :size,
  :last_modified_time)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#name ⇒ String

The name of the pricing plan. The name must be unique to each pricing plan.

Returns:

  • (String)


3126
3127
3128
3129
3130
3131
3132
3133
3134
# File 'lib/aws-sdk-billingconductor/types.rb', line 3126

class UpdatePricingPlanOutput < Struct.new(
  :arn,
  :name,
  :description,
  :size,
  :last_modified_time)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#size ⇒ Integer

The pricing rules count that's currently associated with this pricing plan list.

Returns:

  • (Integer)


3126
3127
3128
3129
3130
3131
3132
3133
3134
# File 'lib/aws-sdk-billingconductor/types.rb', line 3126

class UpdatePricingPlanOutput < Struct.new(
  :arn,
  :name,
  :description,
  :size,
  :last_modified_time)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end