Class: Aws::BillingConductor::Types::UpdatePricingRuleInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the pricing rule to update.

Returns:

  • (String)


3164
3165
3166
3167
3168
3169
3170
3171
3172
3173
# File 'lib/aws-sdk-billingconductor/types.rb', line 3164

class UpdatePricingRuleInput < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :modifier_percentage,
  :tiering)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#description ⇒ String

The new description for the pricing rule.

Returns:

  • (String)


3164
3165
3166
3167
3168
3169
3170
3171
3172
3173
# File 'lib/aws-sdk-billingconductor/types.rb', line 3164

class UpdatePricingRuleInput < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :modifier_percentage,
  :tiering)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#modifier_percentage ⇒ Float

The new modifier to show pricing plan rates as a percentage. Your entry will be rounded to the nearest 2 decimal places.

Returns:

  • (Float)


3164
3165
3166
3167
3168
3169
3170
3171
3172
3173
# File 'lib/aws-sdk-billingconductor/types.rb', line 3164

class UpdatePricingRuleInput < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :modifier_percentage,
  :tiering)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#name ⇒ String

The new name of the pricing rule. The name must be unique to each pricing rule.

Returns:

  • (String)


3164
3165
3166
3167
3168
3169
3170
3171
3172
3173
# File 'lib/aws-sdk-billingconductor/types.rb', line 3164

class UpdatePricingRuleInput < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :modifier_percentage,
  :tiering)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#tiering ⇒ Types::UpdateTieringInput

The set of tiering configurations for the pricing rule.



3164
3165
3166
3167
3168
3169
3170
3171
3172
3173
# File 'lib/aws-sdk-billingconductor/types.rb', line 3164

class UpdatePricingRuleInput < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :modifier_percentage,
  :tiering)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#type ⇒ String

The new pricing rule type.

Returns:

  • (String)


3164
3165
3166
3167
3168
3169
3170
3171
3172
3173
# File 'lib/aws-sdk-billingconductor/types.rb', line 3164

class UpdatePricingRuleInput < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :modifier_percentage,
  :tiering)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end