Class: Aws::BillingConductor::Types::UpdatePricingRuleOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the successfully updated pricing rule.

Returns:

  • (String)


3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
# File 'lib/aws-sdk-billingconductor/types.rb', line 3247

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#associated_pricing_plan_count ⇒ Integer

The pricing plans count that this pricing rule is associated with.

Returns:

  • (Integer)


3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
# File 'lib/aws-sdk-billingconductor/types.rb', line 3247

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#billing_entity ⇒ String

The seller of services provided by Amazon Web Services, their affiliates, or third-party providers selling services via Amazon Web Services Marketplace.

Returns:

  • (String)


3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
# File 'lib/aws-sdk-billingconductor/types.rb', line 3247

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#description ⇒ String

The new description for the pricing rule.

Returns:

  • (String)


3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
# File 'lib/aws-sdk-billingconductor/types.rb', line 3247

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#last_modified_time ⇒ Integer

The most recent time the pricing rule was modified.

Returns:

  • (Integer)


3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
# File 'lib/aws-sdk-billingconductor/types.rb', line 3247

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#modifier_percentage ⇒ Float

The new modifier to show pricing plan rates as a percentage.

Returns:

  • (Float)


3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
# File 'lib/aws-sdk-billingconductor/types.rb', line 3247

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#name ⇒ String

The new name of the pricing rule. The name must be unique to each pricing rule.

Returns:

  • (String)


3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
# File 'lib/aws-sdk-billingconductor/types.rb', line 3247

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#operation ⇒ String

Operation refers to the specific Amazon Web Services covered by this line item. This describes the specific usage of the line item.

If the Scope attribute is set to SKU, this attribute indicates which operation the PricingRule is modifying. For example, a value of RunInstances:0202 indicates the operation of running an Amazon EC2 instance.

Returns:

  • (String)


3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
# File 'lib/aws-sdk-billingconductor/types.rb', line 3247

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#scope ⇒ String

The scope of pricing rule that indicates if it's globally applicable, or it's service-specific.

Returns:

  • (String)


3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
# File 'lib/aws-sdk-billingconductor/types.rb', line 3247

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#service ⇒ String

If the Scope attribute is set to SERVICE, the attribute indicates which service the PricingRule is applicable for.

Returns:

  • (String)


3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
# File 'lib/aws-sdk-billingconductor/types.rb', line 3247

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#tiering ⇒ Types::UpdateTieringInput

The set of tiering configurations for the pricing rule.



3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
# File 'lib/aws-sdk-billingconductor/types.rb', line 3247

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#type ⇒ String

The new pricing rule type.

Returns:

  • (String)


3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
# File 'lib/aws-sdk-billingconductor/types.rb', line 3247

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#usage_type ⇒ String

Usage type is the unit that each service uses to measure the usage of a specific type of resource.

If the Scope attribute is set to SKU, this attribute indicates which usage type the PricingRule is modifying. For example, USW2-BoxUsage:m2.2xlarge describes an M2 High Memory Double Extra Large instance in the US West (Oregon) Region.

Returns:

  • (String)


3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
# File 'lib/aws-sdk-billingconductor/types.rb', line 3247

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end