Class: Aws::BillingConductor::Types::UpdateTieringInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BillingConductor::Types::UpdateTieringInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billingconductor/types.rb
Overview
The set of tiering configurations for the pricing rule.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_tiers ⇒ Array<Types::CustomTier>
The set of custom tiers for the pricing rule.
-
#free_tier ⇒ Types::UpdateFreeTierConfig
The possible Amazon Web Services Free Tier configurations.
Instance Attribute Details
#custom_tiers ⇒ Array<Types::CustomTier>
The set of custom tiers for the pricing rule.
3277 3278 3279 3280 3281 3282 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 3277 class UpdateTieringInput < Struct.new( :free_tier, :custom_tiers) SENSITIVE = [] include Aws::Structure end |
#free_tier ⇒ Types::UpdateFreeTierConfig
The possible Amazon Web Services Free Tier configurations.
3277 3278 3279 3280 3281 3282 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 3277 class UpdateTieringInput < Struct.new( :free_tier, :custom_tiers) SENSITIVE = [] include Aws::Structure end |