Class: Aws::BillingConductor::Types::CreateCustomLineItemInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BillingConductor::Types::CreateCustomLineItemInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billingconductor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Amazon Web Services account in which this custom line item will be applied to.
-
#billing_group_arn ⇒ String
The Amazon Resource Name (ARN) that references the billing group where the custom line item applies to.
-
#billing_period_range ⇒ Types::CustomLineItemBillingPeriodRange
A time range for which the custom line item is effective.
-
#charge_details ⇒ Types::CustomLineItemChargeDetails
A
CustomLineItemChargeDetailsthat describes the charge details for a custom line item. -
#client_token ⇒ String
A unique, case-sensitive identifier that you specify to ensure idempotency of the request.
-
#computation_rule ⇒ String
Specifies how the custom line item charges are computed.
-
#description ⇒ String
The description of the custom line item.
-
#name ⇒ String
The name of the custom line item.
-
#presentation_details ⇒ Types::PresentationObject
Details controlling how the custom line item charges are presented in the bill.
-
#tags ⇒ Hash<String,String>
A map that contains tag keys and tag values that are attached to a custom line item.
Instance Attribute Details
#account_id ⇒ String
The Amazon Web Services account in which this custom line item will be applied to.
680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 680 class CreateCustomLineItemInput < Struct.new( :client_token, :name, :description, :billing_group_arn, :billing_period_range, :tags, :charge_details, :account_id, :computation_rule, :presentation_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#billing_group_arn ⇒ String
The Amazon Resource Name (ARN) that references the billing group where the custom line item applies to.
680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 680 class CreateCustomLineItemInput < Struct.new( :client_token, :name, :description, :billing_group_arn, :billing_period_range, :tags, :charge_details, :account_id, :computation_rule, :presentation_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#billing_period_range ⇒ Types::CustomLineItemBillingPeriodRange
A time range for which the custom line item is effective.
680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 680 class CreateCustomLineItemInput < Struct.new( :client_token, :name, :description, :billing_group_arn, :billing_period_range, :tags, :charge_details, :account_id, :computation_rule, :presentation_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#charge_details ⇒ Types::CustomLineItemChargeDetails
A CustomLineItemChargeDetails that describes the charge details
for a custom line item.
680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 680 class CreateCustomLineItemInput < Struct.new( :client_token, :name, :description, :billing_group_arn, :billing_period_range, :tags, :charge_details, :account_id, :computation_rule, :presentation_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you specify to ensure idempotency of the request. Idempotency ensures that an API request completes no more than one time. With an idempotent request, if the original request completes successfully, any subsequent retries complete successfully without performing any further actions.
A suitable default value is auto-generated. You should normally not need to pass this option.
680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 680 class CreateCustomLineItemInput < Struct.new( :client_token, :name, :description, :billing_group_arn, :billing_period_range, :tags, :charge_details, :account_id, :computation_rule, :presentation_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#computation_rule ⇒ String
Specifies how the custom line item charges are computed.
680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 680 class CreateCustomLineItemInput < Struct.new( :client_token, :name, :description, :billing_group_arn, :billing_period_range, :tags, :charge_details, :account_id, :computation_rule, :presentation_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The description of the custom line item. This is shown on the Bills page in association with the charge value.
680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 680 class CreateCustomLineItemInput < Struct.new( :client_token, :name, :description, :billing_group_arn, :billing_period_range, :tags, :charge_details, :account_id, :computation_rule, :presentation_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The name of the custom line item.
680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 680 class CreateCustomLineItemInput < Struct.new( :client_token, :name, :description, :billing_group_arn, :billing_period_range, :tags, :charge_details, :account_id, :computation_rule, :presentation_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#presentation_details ⇒ Types::PresentationObject
Details controlling how the custom line item charges are presented in the bill. Contains specifications for which service the charges will be shown under.
680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 680 class CreateCustomLineItemInput < Struct.new( :client_token, :name, :description, :billing_group_arn, :billing_period_range, :tags, :charge_details, :account_id, :computation_rule, :presentation_details) SENSITIVE = [:name, :description] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A map that contains tag keys and tag values that are attached to a custom line item.
680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 680 class CreateCustomLineItemInput < Struct.new( :client_token, :name, :description, :billing_group_arn, :billing_period_range, :tags, :charge_details, :account_id, :computation_rule, :presentation_details) SENSITIVE = [:name, :description] include Aws::Structure end |