Class: Aws::BillingConductor::Types::CreatePricingRuleInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BillingConductor::Types::CreatePricingRuleInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billingconductor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#billing_entity ⇒ String
The seller of services provided by Amazon Web Services, their affiliates, or third-party providers selling services via Amazon Web Services Marketplace.
-
#client_token ⇒ String
A unique, case-sensitive identifier that you specify to ensure idempotency of the request.
-
#description ⇒ String
The pricing rule description.
-
#modifier_percentage ⇒ Float
A percentage modifier that’s applied on the public pricing rates.
-
#name ⇒ String
The pricing rule name.
-
#operation ⇒ String
Operation is the specific Amazon Web Services action covered by this line item.
-
#scope ⇒ String
The scope of pricing rule that indicates if it’s globally applicable, or it’s service-specific.
-
#service ⇒ String
If the
Scopeattribute is set toSERVICEorSKU, the attribute indicates which service thePricingRuleis applicable for. -
#tags ⇒ Hash<String,String>
A map that contains tag keys and tag values that are attached to a pricing rule.
-
#tiering ⇒ Types::CreateTieringInput
The set of tiering configurations for the pricing rule.
-
#type ⇒ String
The type of pricing rule.
-
#usage_type ⇒ String
Usage type is the unit that each service uses to measure the usage of a specific type of resource.
Instance Attribute Details
#billing_entity ⇒ String
The seller of services provided by Amazon Web Services, their affiliates, or third-party providers selling services via Amazon Web Services Marketplace.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 824 class CreatePricingRuleInput < Struct.new( :client_token, :name, :description, :scope, :type, :modifier_percentage, :service, :tags, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier that you specify to ensure idempotency of the request. Idempotency ensures that an API request completes no more than one time. With an idempotent request, if the original request completes successfully, any subsequent retries complete successfully without performing any further actions.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 824 class CreatePricingRuleInput < Struct.new( :client_token, :name, :description, :scope, :type, :modifier_percentage, :service, :tags, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The pricing rule description.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 824 class CreatePricingRuleInput < Struct.new( :client_token, :name, :description, :scope, :type, :modifier_percentage, :service, :tags, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#modifier_percentage ⇒ Float
A percentage modifier that’s applied on the public pricing rates. Your entry will be rounded to the nearest 2 decimal places.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 824 class CreatePricingRuleInput < Struct.new( :client_token, :name, :description, :scope, :type, :modifier_percentage, :service, :tags, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The pricing rule name. The names must be unique to each pricing rule.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 824 class CreatePricingRuleInput < Struct.new( :client_token, :name, :description, :scope, :type, :modifier_percentage, :service, :tags, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#operation ⇒ String
Operation is the specific Amazon Web Services action covered by this line item. This describes the specific usage of the line item.
If the Scope attribute is set to SKU, this attribute indicates which operation the PricingRule is modifying. For example, a value of RunInstances:0202 indicates the operation of running an Amazon EC2 instance.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 824 class CreatePricingRuleInput < Struct.new( :client_token, :name, :description, :scope, :type, :modifier_percentage, :service, :tags, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#scope ⇒ String
The scope of pricing rule that indicates if it’s globally applicable, or it’s service-specific.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 824 class CreatePricingRuleInput < Struct.new( :client_token, :name, :description, :scope, :type, :modifier_percentage, :service, :tags, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#service ⇒ String
If the Scope attribute is set to SERVICE or SKU, the attribute indicates which service the PricingRule is applicable for.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 824 class CreatePricingRuleInput < Struct.new( :client_token, :name, :description, :scope, :type, :modifier_percentage, :service, :tags, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A map that contains tag keys and tag values that are attached to a pricing rule.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 824 class CreatePricingRuleInput < Struct.new( :client_token, :name, :description, :scope, :type, :modifier_percentage, :service, :tags, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#tiering ⇒ Types::CreateTieringInput
The set of tiering configurations for the pricing rule.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 824 class CreatePricingRuleInput < Struct.new( :client_token, :name, :description, :scope, :type, :modifier_percentage, :service, :tags, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#type ⇒ String
The type of pricing rule.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 824 class CreatePricingRuleInput < Struct.new( :client_token, :name, :description, :scope, :type, :modifier_percentage, :service, :tags, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#usage_type ⇒ String
Usage type is the unit that each service uses to measure the usage of a specific type of resource.
If the Scope attribute is set to SKU, this attribute indicates which usage type the PricingRule is modifying. For example, USW2-BoxUsage:m2.2xlarge describes an` M2 High Memory Double Extra Large` instance in the US West (Oregon) Region.
824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 824 class CreatePricingRuleInput < Struct.new( :client_token, :name, :description, :scope, :type, :modifier_percentage, :service, :tags, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |