Class: Aws::BillingConductor::Types::CustomTier
- Inherits:
-
Struct
- Object
- Struct
- Aws::BillingConductor::Types::CustomTier
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billingconductor/types.rb
Overview
A custom tier for the pricing rule. Each custom tier applies a rate to the usage that falls within the tier's range.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#begin_range_inclusive ⇒ Float
The inclusive start of the usage range that this tier applies to.
-
#end_range_exclusive ⇒ Float
The exclusive end of the usage range that this tier applies to.
-
#rate_value ⇒ Float
The rate that's applied to the usage that falls within this tier.
Instance Attribute Details
#begin_range_inclusive ⇒ Float
The inclusive start of the usage range that this tier applies to.
1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 1187 class CustomTier < Struct.new( :begin_range_inclusive, :end_range_exclusive, :rate_value) SENSITIVE = [] include Aws::Structure end |
#end_range_exclusive ⇒ Float
The exclusive end of the usage range that this tier applies to. If
you don't specify a value, this tier applies to all usage that is
greater than or equal to BeginRangeInclusive.
1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 1187 class CustomTier < Struct.new( :begin_range_inclusive, :end_range_exclusive, :rate_value) SENSITIVE = [] include Aws::Structure end |
#rate_value ⇒ Float
The rate that's applied to the usage that falls within this tier.
1187 1188 1189 1190 1191 1192 1193 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 1187 class CustomTier < Struct.new( :begin_range_inclusive, :end_range_exclusive, :rate_value) SENSITIVE = [] include Aws::Structure end |