Class: Aws::BillingConductor::Types::UpdateBillingTransferPreferenceOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BillingConductor::Types::UpdateBillingTransferPreferenceOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billingconductor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_billing_transfer_billing_group_creation ⇒ Types::AutoTransferBillingGroupCreationPreference
The updated auto billing group creation preference for the billing transfer.
-
#last_modified_time ⇒ Integer
The most recent time when the preference was modified.
-
#responsibility_transfer_arn ⇒ String
The Amazon Resource Name (ARN) of the billing transfer that the preference applies to.
Instance Attribute Details
#auto_billing_transfer_billing_group_creation ⇒ Types::AutoTransferBillingGroupCreationPreference
The updated auto billing group creation preference for the billing transfer.
2919 2920 2921 2922 2923 2924 2925 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 2919 class UpdateBillingTransferPreferenceOutput < Struct.new( :responsibility_transfer_arn, :auto_billing_transfer_billing_group_creation, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Integer
The most recent time when the preference was modified.
2919 2920 2921 2922 2923 2924 2925 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 2919 class UpdateBillingTransferPreferenceOutput < Struct.new( :responsibility_transfer_arn, :auto_billing_transfer_billing_group_creation, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#responsibility_transfer_arn ⇒ String
The Amazon Resource Name (ARN) of the billing transfer that the preference applies to.
2919 2920 2921 2922 2923 2924 2925 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 2919 class UpdateBillingTransferPreferenceOutput < Struct.new( :responsibility_transfer_arn, :auto_billing_transfer_billing_group_creation, :last_modified_time) SENSITIVE = [] include Aws::Structure end |