Class: Aws::BillingConductor::Types::UpdatePricingRuleInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the pricing rule to update.



3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
# File 'lib/aws-sdk-billingconductor/types.rb', line 3008

class UpdatePricingRuleInput < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :modifier_percentage,
  :tiering)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

The new description for the pricing rule.



3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
# File 'lib/aws-sdk-billingconductor/types.rb', line 3008

class UpdatePricingRuleInput < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :modifier_percentage,
  :tiering)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#modifier_percentageFloat

The new modifier to show pricing plan rates as a percentage. Your entry will be rounded to the nearest 2 decimal places.



3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
# File 'lib/aws-sdk-billingconductor/types.rb', line 3008

class UpdatePricingRuleInput < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :modifier_percentage,
  :tiering)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The new name of the pricing rule. The name must be unique to each pricing rule.



3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
# File 'lib/aws-sdk-billingconductor/types.rb', line 3008

class UpdatePricingRuleInput < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :modifier_percentage,
  :tiering)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#tieringTypes::UpdateTieringInput

The set of tiering configurations for the pricing rule.



3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
# File 'lib/aws-sdk-billingconductor/types.rb', line 3008

class UpdatePricingRuleInput < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :modifier_percentage,
  :tiering)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#typeString

The new pricing rule type.



3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
# File 'lib/aws-sdk-billingconductor/types.rb', line 3008

class UpdatePricingRuleInput < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :modifier_percentage,
  :tiering)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end