Class: Aws::BillingConductor::Types::UpdatePricingRuleOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-billingconductor/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:name, :description]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the successfully updated pricing rule.

Returns:

  • (String)


3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#associated_pricing_plan_countInteger

The pricing plans count that this pricing rule is associated with.

Returns:

  • (Integer)


3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#billing_entityString

The seller of services provided by Amazon Web Services, their affiliates, or third-party providers selling services via Amazon Web Services Marketplace.

Returns:

  • (String)


3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#descriptionString

The new description for the pricing rule.

Returns:

  • (String)


3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#last_modified_timeInteger

The most recent time the pricing rule was modified.

Returns:

  • (Integer)


3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#modifier_percentageFloat

The new modifier to show pricing plan rates as a percentage.

Returns:

  • (Float)


3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#nameString

The new name of the pricing rule. The name must be unique to each pricing rule.

Returns:

  • (String)


3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#operationString

Operation refers to the specific Amazon Web Services covered by this line item. This describes the specific usage of the line item.

If the Scope attribute is set to SKU, this attribute indicates which operation the PricingRule is modifying. For example, a value of RunInstances:0202 indicates the operation of running an Amazon EC2 instance.

Returns:

  • (String)


3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#scopeString

The scope of pricing rule that indicates if it’s globally applicable, or it’s service-specific.

Returns:

  • (String)


3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#serviceString

If the Scope attribute is set to SERVICE, the attribute indicates which service the PricingRule is applicable for.

Returns:

  • (String)


3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#tieringTypes::UpdateTieringInput

The set of tiering configurations for the pricing rule.



3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#typeString

The new pricing rule type.

Returns:

  • (String)


3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end

#usage_typeString

Usage type is the unit that each service uses to measure the usage of a specific type of resource.

If the Scope attribute is set to SKU, this attribute indicates which usage type the PricingRule is modifying. For example, USW2-BoxUsage:m2.2xlarge describes an ‘M2 High Memory Double Extra Large` instance in the US West (Oregon) Region.

Returns:

  • (String)


3091
3092
3093
3094
3095
3096
3097
3098
3099
3100
3101
3102
3103
3104
3105
3106
3107
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091

class UpdatePricingRuleOutput < Struct.new(
  :arn,
  :name,
  :description,
  :scope,
  :type,
  :modifier_percentage,
  :service,
  :associated_pricing_plan_count,
  :last_modified_time,
  :billing_entity,
  :tiering,
  :usage_type,
  :operation)
  SENSITIVE = [:name, :description]
  include Aws::Structure
end