Class: Aws::BillingConductor::Types::UpdatePricingRuleOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::BillingConductor::Types::UpdatePricingRuleOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-billingconductor/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:name, :description]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the successfully updated pricing rule.
-
#associated_pricing_plan_count ⇒ Integer
The pricing plans count that this pricing rule is associated with.
-
#billing_entity ⇒ String
The seller of services provided by Amazon Web Services, their affiliates, or third-party providers selling services via Amazon Web Services Marketplace.
-
#description ⇒ String
The new description for the pricing rule.
-
#last_modified_time ⇒ Integer
The most recent time the pricing rule was modified.
-
#modifier_percentage ⇒ Float
The new modifier to show pricing plan rates as a percentage.
-
#name ⇒ String
The new name of the pricing rule.
-
#operation ⇒ String
Operation refers to the specific Amazon Web Services covered by this line item.
-
#scope ⇒ String
The scope of pricing rule that indicates if it’s globally applicable, or it’s service-specific.
-
#service ⇒ String
If the
Scopeattribute is set toSERVICE, the attribute indicates which service thePricingRuleis applicable for. -
#tiering ⇒ Types::UpdateTieringInput
The set of tiering configurations for the pricing rule.
-
#type ⇒ String
The new pricing rule type.
-
#usage_type ⇒ String
Usage type is the unit that each service uses to measure the usage of a specific type of resource.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the successfully updated pricing rule.
3091 3092 3093 3094 3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091 class UpdatePricingRuleOutput < Struct.new( :arn, :name, :description, :scope, :type, :modifier_percentage, :service, :associated_pricing_plan_count, :last_modified_time, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#associated_pricing_plan_count ⇒ Integer
The pricing plans count that this pricing rule is associated with.
3091 3092 3093 3094 3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091 class UpdatePricingRuleOutput < Struct.new( :arn, :name, :description, :scope, :type, :modifier_percentage, :service, :associated_pricing_plan_count, :last_modified_time, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#billing_entity ⇒ String
The seller of services provided by Amazon Web Services, their affiliates, or third-party providers selling services via Amazon Web Services Marketplace.
3091 3092 3093 3094 3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091 class UpdatePricingRuleOutput < Struct.new( :arn, :name, :description, :scope, :type, :modifier_percentage, :service, :associated_pricing_plan_count, :last_modified_time, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#description ⇒ String
The new description for the pricing rule.
3091 3092 3093 3094 3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091 class UpdatePricingRuleOutput < Struct.new( :arn, :name, :description, :scope, :type, :modifier_percentage, :service, :associated_pricing_plan_count, :last_modified_time, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#last_modified_time ⇒ Integer
The most recent time the pricing rule was modified.
3091 3092 3093 3094 3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091 class UpdatePricingRuleOutput < Struct.new( :arn, :name, :description, :scope, :type, :modifier_percentage, :service, :associated_pricing_plan_count, :last_modified_time, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#modifier_percentage ⇒ Float
The new modifier to show pricing plan rates as a percentage.
3091 3092 3093 3094 3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091 class UpdatePricingRuleOutput < Struct.new( :arn, :name, :description, :scope, :type, :modifier_percentage, :service, :associated_pricing_plan_count, :last_modified_time, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#name ⇒ String
The new name of the pricing rule. The name must be unique to each pricing rule.
3091 3092 3093 3094 3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091 class UpdatePricingRuleOutput < Struct.new( :arn, :name, :description, :scope, :type, :modifier_percentage, :service, :associated_pricing_plan_count, :last_modified_time, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#operation ⇒ String
Operation refers to the specific Amazon Web Services covered by this line item. This describes the specific usage of the line item.
If the Scope attribute is set to SKU, this attribute indicates which operation the PricingRule is modifying. For example, a value of RunInstances:0202 indicates the operation of running an Amazon EC2 instance.
3091 3092 3093 3094 3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091 class UpdatePricingRuleOutput < Struct.new( :arn, :name, :description, :scope, :type, :modifier_percentage, :service, :associated_pricing_plan_count, :last_modified_time, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#scope ⇒ String
The scope of pricing rule that indicates if it’s globally applicable, or it’s service-specific.
3091 3092 3093 3094 3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091 class UpdatePricingRuleOutput < Struct.new( :arn, :name, :description, :scope, :type, :modifier_percentage, :service, :associated_pricing_plan_count, :last_modified_time, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#service ⇒ String
If the Scope attribute is set to SERVICE, the attribute indicates which service the PricingRule is applicable for.
3091 3092 3093 3094 3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091 class UpdatePricingRuleOutput < Struct.new( :arn, :name, :description, :scope, :type, :modifier_percentage, :service, :associated_pricing_plan_count, :last_modified_time, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#tiering ⇒ Types::UpdateTieringInput
The set of tiering configurations for the pricing rule.
3091 3092 3093 3094 3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091 class UpdatePricingRuleOutput < Struct.new( :arn, :name, :description, :scope, :type, :modifier_percentage, :service, :associated_pricing_plan_count, :last_modified_time, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#type ⇒ String
The new pricing rule type.
3091 3092 3093 3094 3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091 class UpdatePricingRuleOutput < Struct.new( :arn, :name, :description, :scope, :type, :modifier_percentage, :service, :associated_pricing_plan_count, :last_modified_time, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |
#usage_type ⇒ String
Usage type is the unit that each service uses to measure the usage of a specific type of resource.
If the Scope attribute is set to SKU, this attribute indicates which usage type the PricingRule is modifying. For example, USW2-BoxUsage:m2.2xlarge describes an ‘M2 High Memory Double Extra Large` instance in the US West (Oregon) Region.
3091 3092 3093 3094 3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 |
# File 'lib/aws-sdk-billingconductor/types.rb', line 3091 class UpdatePricingRuleOutput < Struct.new( :arn, :name, :description, :scope, :type, :modifier_percentage, :service, :associated_pricing_plan_count, :last_modified_time, :billing_entity, :tiering, :usage_type, :operation) SENSITIVE = [:name, :description] include Aws::Structure end |